diff --git a/cis/private/bildupload.php b/cis/private/bildupload.php
index ca761d524..8b73c92ec 100644
--- a/cis/private/bildupload.php
+++ b/cis/private/bildupload.php
@@ -32,14 +32,6 @@ require_once('../../include/akte.class.php');
$PHP_SELF = $_SERVER['PHP_SELF'];
echo "
";
-//wandelt einen String in HEX-Werte um
-function strhex($string)
-{
- $hex="";
- for ($i=0;$idokument_kurzbz = 'Lichtbil';
$akte->person_id = $_GET['person_id'];
- $akte->inhalt = strhex($content);
+ $akte->inhalt = base64_encode($content);
$akte->mimetype = "image/jpg";
$akte->erstelltam = date('Y-m-d H:i:s');
$akte->gedruckt = false;
@@ -156,13 +148,13 @@ if(isset($_POST['submitbild']))
//auslesen
$content = fread($fp, filesize($filename));
fclose($fp);
- //in HEX-Werte umrechnen
- $content = strhex($content);
+ //in base64-Werte umrechnen
+ $content = base64_encode($content);
$person = new person();
if($person->load($_GET['person_id']))
{
//HEX Wert in die Datenbank speichern
$person->foto = $content;
$person->new = false;
if($person->save())
@@ -156,13 +148,13 @@ if(isset($_POST['submitbild']))
if($person->load($_GET['person_id']))
{
- //HEX Wert in die Datenbank speichern
+ //base64 Wert in die Datenbank speichern
$person->foto = $content;
$person->new = false;